@@ -6,7 +6,7 @@ use utf8;
 use POSIX qw/floor/;
 
 # ABSTRACT: Numbers to words in russian (without currency, but with specified gender)
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 # AUTHORITY
 
 use Exporter qw/import/;
@@ -132,7 +132,9 @@ sub num2rus_cardinal {
 }
 
 sub _get_string {
-    my $sum     = shift // return;
+    my $sum     = shift;
+    return unless defined $sum;
+
     my $nominal = shift;
     my $gender  = shift;
     my ( $result, $nom ) = ( '', -1 );
@@ -195,7 +197,7 @@ Lingua::RU::Num2Word - Numbers to words in russian (without currency, but with s
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
